Commit f3d40621900c3ed697cf68d38292d323a1685110

Thomas de Grivel 2023-01-21T15:08:46

help2man-1.40.5

1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
1230
1231
1232
1233
1234
1235
1236
1237
1238
1239
1240
1241
1242
1243
1244
1245
1246
1247
1248
1249
1250
1251
1252
1253
1254
1255
1256
1257
1258
1259
1260
1261
1262
1263
1264
1265
1266
1267
1268
1269
1270
1271
1272
1273
1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
1342
1343
1344
1345
1346
1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
1366
1367
1368
1369
1370
1371
1372
1373
1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
1392
1393
1394
1395
1396
1397
1398
1399
1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
diff --git a/README b/README
index 9aebb33..c2dfb97 100644
--- a/README
+++ b/README
@@ -1,10 +1,10 @@
-		README for GNU help2man version 1.40.4
+		README for GNU help2man version 1.40.5
 
 help2man is a script to create simple man pages from the --help and
 --version output of programs.
 
   http://www.gnu.org/software/help2man/
-  ftp://ftp.gnu.org/gnu/help2man/help2man-1.40.4.tar.gz
+  ftp://ftp.gnu.org/gnu/help2man/help2man-1.40.5.tar.gz
 
   git://anonscm.debian.org/users/bod/help2man.git
   http://anonscm.debian.org/git/users/bod/help2man.git
diff --git a/THANKS b/THANKS
index 5c8de2e..52c2ace 100644
--- a/THANKS
+++ b/THANKS
@@ -29,6 +29,7 @@ Jim Meyering			<jim@meyering.net>
 Dave Morrison			<dave@bnl.gov>
 Peter Moulder			<reiter@netspace.net.au>
 NIIBE Yutaka			<gniibe@fsij.org>
+Miroslav Nikolic		<miroslavnikolic@rocketmail.com>
 Daniel Nylander			<yeager@lidkoping.net>
 OKUJI Yoshinori			<okuji@kuicr.kyoto-u.ac.jp>
 François Pinard			<pinard@iro.umontreal.ca>
diff --git a/debian/changelog b/debian/changelog
index 951ae2d..1d6ee16 100644
--- a/debian/changelog
+++ b/debian/changelog
@@ -1,3 +1,13 @@
+help2man (1.40.5) unstable; urgency=low
+
+  * Clean up some lintian warnings: build-targets, source format and
+    standards version.
+  * Add Serbian translation (thanks to Miroslav Nikolic).
+  * Fix trivial translation changes due to additional copyright year.
+  * Minor fix to Italian translation.
+
+ -- Brendan O'Dea <bod@debian.org>  Mon, 02 Jan 2012 20:50:50 +1100
+
 help2man (1.40.4) unstable; urgency=low
 
   * Update Brazilian Portuguese translation (thanks to Rodolfo Ribeiro
diff --git a/debian/control b/debian/control
index e5f50da..14cf5f1 100644
--- a/debian/control
+++ b/debian/control
@@ -2,7 +2,7 @@ Source: help2man
 Section: devel
 Priority: optional
 Maintainer: Brendan O'Dea <bod@debian.org>
-Standards-Version: 3.9.1
+Standards-Version: 3.9.2
 Build-Depends: perl (>= 5.8.0-7), debhelper (>= 8), gettext (>= 0.12.1), liblocale-gettext-perl
 Vcs-Git: git://anonscm.debian.org/users/bod/help2man.git
 Vcs-Browser: http://anonscm.debian.org/gitweb/?p=users/bod/help2man.git
diff --git a/debian/rules b/debian/rules
index 5a2d1ca..4ac59c6 100755
--- a/debian/rules
+++ b/debian/rules
@@ -10,7 +10,8 @@ ifneq ($(DEB_BUILD_GNU_TYPE),$(DEB_HOST_GNU_TYPE))
  CONFARGS = --host=$(DEB_HOST_GNU_TYPE)
 endif
 
-build: build-stamp
+build: build-arch build-indep
+build-arch build-indep: build-stamp
 build-stamp:
 	dh_testdir
 	./configure --prefix=/usr --enable-nls --mandir='$${prefix}/share/man' \
diff --git a/debian/source/format b/debian/source/format
new file mode 100644
index 0000000..89ae9db
--- /dev/null
+++ b/debian/source/format
@@ -0,0 +1 @@
+3.0 (native)
diff --git a/help2man.1 b/help2man.1
index 9a1bfcd..c0712c9 100644
--- a/help2man.1
+++ b/help2man.1
@@ -1,5 +1,5 @@
-.\" DO NOT MODIFY THIS FILE!  It was generated by help2man 1.40.4.
-.TH HELP2MAN "1" "June 2011" "help2man 1.40.4" "User Commands"
+.\" DO NOT MODIFY THIS FILE!  It was generated by help2man 1.40.5.
+.TH HELP2MAN "1" "January 2012" "help2man 1.40.5" "User Commands"
 .SH NAME
 help2man \- generate a simple manual page
 .SH SYNOPSIS
@@ -132,7 +132,7 @@ Written by Brendan O'Dea <bod@debian.org>
 Report bugs to <bug\-help2man@gnu.org>.
 .SH COPYRIGHT
 Copyright \(co 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, 2010,
-2011 Free Software Foundation, Inc.
+2011, 2012 Free Software Foundation, Inc.
 .br
 This is free software; see the source for copying conditions.  There is NO
 warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
diff --git a/help2man.de.1 b/help2man.de.1
index 8413dbe..24be3db 100644
--- a/help2man.de.1
+++ b/help2man.de.1
@@ -1,5 +1,5 @@
-.\" DO NOT MODIFY THIS FILE!  It was generated by help2man 1.40.4.
-.TH HELP2MAN "1" "Juni 2011" "help2man 1.40.4" "Benutzerkommandos"
+.\" DO NOT MODIFY THIS FILE!  It was generated by help2man 1.40.5.
+.TH HELP2MAN "1" "Januar 2012" "help2man 1.40.5" "Benutzerkommandos"
 .SH NAME
 help2man \- generiert eine einfache Handbuchseite
 .SH ÜBERSICHT
@@ -139,7 +139,7 @@ Geschrieben von Brendan O'Dea <bod@debian.org>
 Berichten Sie Fehler an <bug\-help2man@gnu.org>.
 .SH COPYRIGHT
 Copyright \(co 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, 2010
-2011 Free Software Foundation, Inc.
+2011, 2012 Free Software Foundation, Inc.
 .br
 Dies ist freie Software. Lesen Sie die Quelle, um die Kopierbedingungen
 zu erhalten. Es gibt KEINE Gewährleistung, nicht einmal für
diff --git a/help2man.el.1 b/help2man.el.1
index 55292ee..27c55b6 100644
--- a/help2man.el.1
+++ b/help2man.el.1
@@ -1,5 +1,5 @@
-.\" DO NOT MODIFY THIS FILE!  It was generated by help2man 1.40.4.
-.TH HELP2MAN "1" "Ιούνιος 2011" "help2man 1.40.4" "Εντολές χρήστη"
+.\" DO NOT MODIFY THIS FILE!  It was generated by help2man 1.40.5.
+.TH HELP2MAN "1" "Ιανουάριος 2012" "help2man 1.40.5" "Εντολές χρήστη"
 .SH NAME
 help2man \- δημιουργία απλής σελίδας εγχειριδίου
 .SH DESCRIPTION
@@ -129,11 +129,11 @@ or
     ftp://ftp.gnu.org/gnu/help2man/
 .SH COPYRIGHT
 Copyright \(co 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, 2010,
-2011 Free Software Foundation, Inc.
-This is free software; see the source for copying conditions.  There is NO
-warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+2011, 2012 Free Software Foundation, Inc.
+Αυτό είναι ελεύθερο λογισμικό. Δείτε τον πηγαίο κώδικα για όρους αντιγραφής. ΔΕΝ δίδεται
+εγγύηση, ούτε ακόμα ΕΜΠΟΡΕΥΣΙΜΟΤΗΤΑΣ ή ΚΑΤΑΛΛΗΛΟΤΗΤΑΣ ΓΙΑ ΣΥΓΚΕΚΡΙΜΕΝΟ ΣΚΟΠΟ.
 .PP
-Written by Brendan O'Dea <bod@debian.org>
+Συγγραφή: Brendan O'Dea <bod@debian.org>
 .SH "SEE ALSO"
 Η πλήρης τεκμηρίωση για
 .B help2man
diff --git a/help2man.eo.1 b/help2man.eo.1
index 3b37781..edfd0ef 100644
--- a/help2man.eo.1
+++ b/help2man.eo.1
@@ -1,5 +1,5 @@
-.\" DO NOT MODIFY THIS FILE!  It was generated by help2man 1.40.4.
-.TH HELP2MAN "1" "2011-06" "help2man 1.40.4" "Uzant-Komandoj"
+.\" DO NOT MODIFY THIS FILE!  It was generated by help2man 1.40.5.
+.TH HELP2MAN "1" "2012-01" "help2man 1.40.5" "Uzant-Komandoj"
 .SH NOMO
 help2man \- generas simplan man-paĝon
 .SH RESUMO
@@ -130,7 +130,7 @@ Verkite de Brendan O'Dea <bod@debian.org>
 Raportu misojn al <bug\-help2man@gnu.org>.
 .PP
 Kopirajto (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, 2010,
-2011 Free Software Foundation, Inc.
+2011, 2012 Free Software Foundation, Inc.
 Tio ĉi estas libera programaro; rigardu la fontkodon por kopi\-kondiĉoj. Estas NENIU
 garantio; eĉ ne por MERKATIGEBLO aŭ TAŬGECO POR SPECIFA CELO.
 .SH "VIDU ANKAŬ"
diff --git a/help2man.fi.1 b/help2man.fi.1
index 5249069..dc2cf51 100644
--- a/help2man.fi.1
+++ b/help2man.fi.1
@@ -1,5 +1,5 @@
-.\" DO NOT MODIFY THIS FILE!  It was generated by help2man 1.40.4.
-.TH HELP2MAN "1" "kesäkuu 2011" "help2man 1.40.4" "Käyttäjän sovellukset"
+.\" DO NOT MODIFY THIS FILE!  It was generated by help2man 1.40.5.
+.TH HELP2MAN "1" "tammikuu 2012" "help2man 1.40.5" "Käyttäjän sovellukset"
 .SH NIMI
 help2man \- luo yksinkertainen man-sivu
 .SH YLEISKATSAUS
@@ -135,7 +135,7 @@ Lähetä raportit ohjelmistovioista (englanniksi) osoitteeseen
 <bug\-help2man@gnu.org>.
 .SH TEKIJÄNOIKEUDET
 Copyright \(co 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, 2010,
-2011 Free Software Foundation, Inc.
+2011, 2012 Free Software Foundation, Inc.
 Tämä on vapaa ohjelmist; katsokaa kopiointiehdot lähdekoodista. Takuuta EI OLE;
 ei edes KAUPALLISESTI HYVÄKSYTTÄVÄSTÄ LAADUSTA tai SOPIVUUDESTA TIETTYYN
 TARKOITUKSEEN.
diff --git a/help2man.fr.1 b/help2man.fr.1
index 24cc1f2..9cfa2db 100644
--- a/help2man.fr.1
+++ b/help2man.fr.1
@@ -1,5 +1,5 @@
-.\" DO NOT MODIFY THIS FILE!  It was generated by help2man 1.40.4.
-.TH HELP2MAN "1" "juin 2011" "help2man 1.40.4" "Commandes"
+.\" DO NOT MODIFY THIS FILE!  It was generated by help2man 1.40.5.
+.TH HELP2MAN "1" "janvier 2012" "help2man 1.40.5" "Commandes"
 .SH NOM
 help2man \- crée une page de manuel sommaire
 .SH SYNOPSIS
@@ -144,7 +144,7 @@ La dernière version de cette distribution est disponible en ligne sur\\ :
 Signaler les bogues à <bug\-help2man@gnu.org>.
 .SH COPYRIGHT
 Copyright \(co 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, 2010,
-2011 Free Software Foundation, Inc.
+2011, 2012 Free Software Foundation, Inc.
 .br
 Ce logiciel est libre\ ; voir les sources pour les conditions de
 reproduction. AUCUNE garantie n'est donnée, pas même la garantie
diff --git a/help2man.it.1 b/help2man.it.1
index 9083af9..99da8cb 100644
--- a/help2man.it.1
+++ b/help2man.it.1
@@ -1,5 +1,5 @@
-.\" DO NOT MODIFY THIS FILE!  It was generated by help2man 1.40.4.
-.TH HELP2MAN "1" "giugno 2011" "help2man 1.40.4" "Comandi utente"
+.\" DO NOT MODIFY THIS FILE!  It was generated by help2man 1.40.5.
+.TH HELP2MAN "1" "gennaio 2012" "help2man 1.40.5" "Comandi utente"
 .SH NOME
 help2man \- genera una semplice pagina di manuale
 .SH SINTASSI
@@ -65,8 +65,8 @@ Include lo stderr nell'analisi dell'output dell'opzione
 Nell'output generato possono essere inclusi materiali aggiuntivi con le opzioni
 .B \-\-include
 e
-.B \-\-opt\-include
-.  Il formato è semplice:
+.BR \-\-opt\-include .
+Il formato è semplice:
 
     [sezione]
     testo
@@ -133,7 +133,7 @@ Scritto da Brendan O'Dea <bod@debian.org>
 Segnalare i bug a <bug\-help2man@gnu.org>.
 .SH COPYRIGHT
 Copyright \(co 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, 2010,
-2011 Free Software Foundation, Inc.
+2011, 2012 Free Software Foundation, Inc.
 .br
 Questo è software libero; si vedano i sorgenti per le condizioni di copia.
 NON c'è alcuna garanzia; neppure di COMMERCIABILITÀ o di IDONEITÀ A UNO
diff --git a/help2man.ja.1 b/help2man.ja.1
index c95b24e..7df745d 100644
--- a/help2man.ja.1
+++ b/help2man.ja.1
@@ -1,5 +1,5 @@
-.\" DO NOT MODIFY THIS FILE!  It was generated by help2man 1.40.4.
-.TH HELP2MAN "1" "2011年6月" "help2man 1.40.4" "ユーザーコマンド"
+.\" DO NOT MODIFY THIS FILE!  It was generated by help2man 1.40.5.
+.TH HELP2MAN "1" "2012年1月" "help2man 1.40.5" "ユーザーコマンド"
 .SH 名前
 help2man \- 簡易マニュアルページの生成
 .SH 書式
@@ -133,7 +133,7 @@ RCS のキーワードなどに使用することができる。
 バグを発見した場合は <bug\-help2man@gnu.org> に報告されたい。
 .SH 著作権
 Copyright \(co 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, 2010,
-2011 Free Software Foundation, Inc.
+2011, 2012 Free Software Foundation, Inc.
 This is free software; see the source for copying conditions.  There is NO
 warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 .SH 関連項目
diff --git a/help2man.pl.1 b/help2man.pl.1
index 128a4be..396f03e 100644
--- a/help2man.pl.1
+++ b/help2man.pl.1
@@ -1,5 +1,5 @@
-.\" DO NOT MODIFY THIS FILE!  It was generated by help2man 1.40.4.
-.TH HELP2MAN "1" "czerwiec 2011" "help2man 1.40.4" "Polecenia użytkownika"
+.\" DO NOT MODIFY THIS FILE!  It was generated by help2man 1.40.5.
+.TH HELP2MAN "1" "styczeń 2012" "help2man 1.40.5" "Polecenia użytkownika"
 .SH NAZWA
 help2man \- generowanie prostej strony podręcznika
 .SH SKŁADNIA
@@ -134,7 +134,7 @@ Program napisał Brendan O'Dea <bod@debian.org>
 Błędy prosimy zgłaszać na adres <bug\-help2man@gnu.org>.
 .SH COPYRIGHT
 Copyright \(co 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, 2010,
-2011 Free Software Foundation, Inc.
+2011, 2012 Free Software Foundation, Inc.
 .br
 Ten program jest darmowy; warunki kopiowania są opisane w źródłach.
 Autorzy nie dają ŻADNYCH gwarancji, w tym również gwarancji PRZYDATNOŚCI
diff --git a/help2man.pt_BR.1 b/help2man.pt_BR.1
index 9ca8b0a..f85161a 100644
--- a/help2man.pt_BR.1
+++ b/help2man.pt_BR.1
@@ -1,5 +1,5 @@
-.\" DO NOT MODIFY THIS FILE!  It was generated by help2man 1.40.4.
-.TH HELP2MAN "1" "junho de 2011" "help2man 1.40.4" "Comandos de usuário"
+.\" DO NOT MODIFY THIS FILE!  It was generated by help2man 1.40.5.
+.TH HELP2MAN "1" "janeiro de 2012" "help2man 1.40.5" "Comandos de usuário"
 .SH NOME
 help2man \- gera uma página de manual simples
 .SH SINOPSE
@@ -135,7 +135,7 @@ Escrito por Brendan O'Dea <bod@debian.org>
 Relate problemas para <bug\-help2man@gnu.org>.
 .SH "DIREITOS AUTORAIS"
 Copyright \(co 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, 2010,
-2011 Free Software Foundation, Inc.
+2011, 2012 Free Software Foundation, Inc.
 Este é um software livre; veja o código\-fonte para as condições de cópia.
 NÃO HÁ GARANTIAS; nem mesmo para COMERCIALIZAÇÃO ou ADAPTAÇÃO PARA UM
 FIM ESPECÍFICO.
diff --git a/help2man.ru.1 b/help2man.ru.1
index 8e2a878..8db0f60 100644
--- a/help2man.ru.1
+++ b/help2man.ru.1
@@ -1,5 +1,5 @@
-.\" DO NOT MODIFY THIS FILE!  It was generated by help2man 1.40.4.
-.TH HELP2MAN "1" "20.06.2011" "help2man 1.40.4" "Пользовательские команды"
+.\" DO NOT MODIFY THIS FILE!  It was generated by help2man 1.40.5.
+.TH HELP2MAN "1" "02.01.2012" "help2man 1.40.5" "Пользовательские команды"
 .SH ИМЯ
 help2man \- генерирует простую справочную страницу
 .SH ОБЗОР
@@ -134,7 +134,7 @@ help2man генерирует справочную страницу исходя
 Об ошибках сообщайте по адресу: <bug\-help2man@gnu.org>.
 .SH COPYRIGHT
 Copyright \(co 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, 2010,
-2011 Free Software Foundation, Inc.
+2011, 2012 Free Software Foundation, Inc.
 .br
 Это свободное ПО; условия копирования см. в исходном коде.
 Нет НИКАКИХ ГАРАНТИЙ; даже подразумеваемыми гарантиями
diff --git a/help2man.sr.1 b/help2man.sr.1
new file mode 100644
index 0000000..1286b7e
--- /dev/null
+++ b/help2man.sr.1
@@ -0,0 +1,149 @@
+.\" DO NOT MODIFY THIS FILE!  It was generated by help2man 1.40.5.
+.TH ГНУ "1" "јануар 2012." "ГНУ help2man 1.40.5" "Корисничке наредбе"
+.SH НАЗИВ
+help2man \— ствара страницу упутства
+.SH УВОД
+.B help2man
+[\fIОПЦИЈА\fR]... \fIИЗВРШНИ\fR
+.SH ОПИС
+„help2man“ ствара странице упутства из „\-\-help“ и „\-\-version“ излаза.
+.TP
+\fB\-n\fR, \fB\-\-name\fR=\fIНИСКА\fR
+опис пасуса НАЗИВ
+.TP
+\fB\-s\fR, \fB\-\-section\fR=\fIОДЕЉАК\fR
+број одељка за страницу упутства (1, 6, 8)
+.TP
+\fB\-m\fR, \fB\-\-manual\fR=\fIТЕКСТ\fR
+назив упутства (Корисничке наредбе, ...)
+.TP
+\fB\-S\fR, \fB\-\-source\fR=\fIТЕКСТ\fR
+извор програма (3ЦЦ, Дебијан, ...)
+.TP
+\fB\-L\fR, \fB\-\-locale\fR=\fIНИСКА\fR
+бира локалитет (основно је "C")
+.TP
+\fB\-i\fR, \fB\-\-include\fR=\fIДАТОТЕКА\fR
+укључује материјал из „ДАТОТЕКЕ“
+.TP
+\fB\-I\fR, \fB\-\-opt\-include\fR=\fIДАТОТЕКА\fR
+укључује материјал из ДАТОТЕКЕ ако постоји
+.TP
+\fB\-o\fR, \fB\-\-output\fR=\fIДАТОТЕКА\fR
+шаље излаз у ДАТОТЕКУ
+.TP
+\fB\-p\fR, \fB\-\-info\-page\fR=\fIТЕКСТ\fR
+назив Тексинфо упутства
+.TP
+\fB\-N\fR, \fB\-\-no\-info\fR
+потискује указивач на Тексинфо упутства
+.TP
+\fB\-l\fR, \fB\-\-libtool\fR
+искључује „lt\-“ из назива програма
+.TP
+\fB\-\-help\fR
+исписује ову помоћ, затим излази
+.TP
+\fB\-\-version\fR
+исписује број издања, затим излази
+.PP
+ИЗВРШНИ треба да прихвати „\-\-help“ и „\-\-version“ опције и да произведе излаз
+на стандардном излазу иако алтернативе могу бити наведене користећи:
+.TP
+\fB\-h\fR, \fB\-\-help\-option\fR=\fIНИСКА\fR
+ниска опције помоћи
+.TP
+\fB\-v\fR, \fB\-\-version\-option\fR=\fIНИСКА\fR
+ниска опције издања
+.TP
+\fB\-\-version\-string\fR=\fIНИСКА\fR
+ниска издања
+.TP
+\fB\-\-no\-discard\-stderr\fR
+укључује стандардну грешку при обради излаза опције
+.PP
+Грешке пријавите на <bug\-help2man@gnu.org>.
+.PP
+Ауторска права (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, 2010,
+2011, 2012 Задужбина слободног софтвера, Инц.
+Ово је слободан софтвер; погледајте извор за услове умножавања.  Нема НИКАКВЕ
+гаранције; чак ни за ТРЖИШНУ ВРЕДНОСТ или ПРИЛАГОЂЕНОСТИ ПОСЕБНОЈ НАМЕНИ.
+.PP
+Написао је Брендан О'Деа <bod@debian.org>
+.SH "УКЉУЧИ ДАТОТЕКЕ"
+Додатни материјал може бити укључен у створени резултат употребом
+.B \-\-include
+и
+.B \-\-opt\-include
+опцијом.  Облик је једноставан:
+
+    [одељак]
+    текст
+
+    /шаблон/
+    текст
+
+Блокови дословног *рофф текста су уметнути у резултату било на
+почетку датог
+.BI [ одељка ]
+(неосетљив на величину слова), или након поклапања пасуса са
+.BI / шаблоном /\fR.
+
+Шаблони користе синтаксу регуларног израза Перла и за њима могу да
+стоје
+.IR i ,
+.I s
+или
+.I m
+измењивачи (погледајте
+.BR perlre (1)).
+
+Редови пре првог одељка или шаблона који почињу са „\-“ се
+обрађују као опције.  Све остало се немо занемарује и може бити
+коришћено за напомене, РЦС кључне речи и слично.
+
+Поредак резултата одељка (за оне укључене) је:
+
+    НАЗИВ
+    УВОД
+    ОПИС
+    ОПЦИЈЕ
+    ОКРУЖЕЊЕ
+    ДАТОТЕКЕ
+    ПРИМЕРИ
+    \fIостало\fR
+    АУТОР
+    ПРИЈАВЉИВАЊЕ ГРЕШАКА
+    АУТОРСКА ПРАВА
+    ПОГЛЕДАЈТЕ ТАКОЂЕ
+
+Сваки
+.B [НАЗИВ]
+или
+.B [УВОД]
+одељак који се појави у датотеци укључивања ће заменити оно што је
+самостално произведено (ипак можете још увек да прескочите
+модел са
+.B --name
+ако је затражено).
+
+Остали одељци су прикачени самостално произведеном резултату за
+стандардне одељке дате изнад, или укључени у
+.I осталим
+(изнад) по редоследу како су проналажени у датотеци укључивања.
+.SH ДОСТУПНОСТ
+Најновије издање ове расподеле је доступно на мрежи са:
+
+    ftp://ftp.gnu.org/gnu/help2man/
+.SH "ПОГЛЕДАЈТЕ ТАКОЂЕ"
+Потпуна документација за
+.B ГНУ
+је одржавана као Тексинфо упутство.  Ако су
+.B инфо
+и
+.B ГНУ
+исправно инсталирани на вашем сајту, наредба
+.IP
+.B инфо ГНУ
+.PP
+треба да вам да приступ потпуном упутству.
diff --git a/help2man.sv.1 b/help2man.sv.1
index 8d0325f..ae76e2b 100644
--- a/help2man.sv.1
+++ b/help2man.sv.1
@@ -1,5 +1,5 @@
-.\" DO NOT MODIFY THIS FILE!  It was generated by help2man 1.40.4.
-.TH HELP2MAN "1" "juni 2011" "help2man 1.40.4" "Användarkommandon"
+.\" DO NOT MODIFY THIS FILE!  It was generated by help2man 1.40.5.
+.TH HELP2MAN "1" "januari 2012" "help2man 1.40.5" "Användarkommandon"
 .SH NAMN
 help2man \- generera en enkel manualsida
 .SH BESKRIVNING
@@ -124,15 +124,16 @@ för standardsektionerna angivna ovan, eller inkluderas vid
 Senaste versionen av den här utgåvan finns tillgänglig online från:
 
     ftp://ftp.gnu.org/gnu/help2man/
+.SH UPPHOVSMAN
+Skrivet av Brendan O'Dea <bod@debian.org>
 .SH "RAPPORTERA FEL"
 Report bugs to <bug\-help2man@gnu.org>.
 .SH COPYRIGHT
 Copyright \(co 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, 2010,
-2011 Free Software Foundation, Inc.
-This is free software; see the source for copying conditions.  There is NO
-warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-.PP
-Written by Brendan O'Dea <bod@debian.org>
+2011, 2012 Free Software Foundation, Inc.
+.br
+Det här är fri programvara; se källkoden för kopieringsvillkor.  Det finns INGEN
+garanti; inte ens för SÄLJBARHET eller LÄMPLIGHET FÖR SPECIELLT ÄNDAMÅL.
 .SH "SE OCKSÅ"
 Den fullständiga dokumentationen för
 .B help2man
diff --git a/help2man.uk.1 b/help2man.uk.1
index f2ad742..e2981b0 100644
--- a/help2man.uk.1
+++ b/help2man.uk.1
@@ -1,5 +1,5 @@
-.\" DO NOT MODIFY THIS FILE!  It was generated by help2man 1.40.4.
-.TH HELP2MAN "1" "20.06.11" "help2man 1.40.4" "Команди користувача"
+.\" DO NOT MODIFY THIS FILE!  It was generated by help2man 1.40.5.
+.TH HELP2MAN "1" "02.01.12" "help2man 1.40.5" "Команди користувача"
 .SH НАЗВА
 help2man \— програма для створення простих сторінок довідника
 .SH "КОРОТКИЙ ОПИС"
@@ -128,7 +128,7 @@ or
 .SH "Як надіслати звіт про вади"
 Про вади повідомляйте на адресу <bug\-help2man@gnu.org>.
 .PP
-© Free Software Foundation, Inc., 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, 2010, 2011
+© Free Software Foundation, Inc., 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, 2010, 2011, 2012
 Це програмне забезпечення є вільним, умови копіювання викладено у його початкових кодах. Умовами ліцензування програми НЕ передбачено жодних гарантій, зокрема гарантій працездатності або придатності для певної мети.
 .PP
 Автором програми є Brendan O'Dea <bod@debian.org>
diff --git a/help2man.vi.1 b/help2man.vi.1
index 98a51a7..b1b92a3 100644
--- a/help2man.vi.1
+++ b/help2man.vi.1
@@ -1,5 +1,5 @@
-.\" DO NOT MODIFY THIS FILE!  It was generated by help2man 1.40.4.
-.TH HELP2MAN "1" "Tháng sáu 2011" "help2man 1.40.4" "Lệnh người dùng"
+.\" DO NOT MODIFY THIS FILE!  It was generated by help2man 1.40.5.
+.TH HELP2MAN "1" "Tháng một 2012" "help2man 1.40.5" "Lệnh người dùng"
 .SH TÊN
 help2man \- tạo một trang hướng dẫn đơn giản
 .SH "MÔ TẢ"
@@ -132,7 +132,7 @@ Phiên bản mới nhất của bản phân phối này có sẵn sàng trực t
     ftp://ftp.gnu.org/gnu/help2man/
 .SH "BẢN QUYỀN"
 Copyright \(co 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, 2010,
-2011 Free Software Foundation, Inc.
+2011, 2012 Free Software Foundation, Inc.
 This is free software; see the source for copying conditions.  There is NO
 warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 .PP
diff --git a/locales b/locales
index e6a94a4..c6ca9dd 100644
--- a/locales
+++ b/locales
@@ -8,6 +8,7 @@ ja	ja_JP.UTF-8
 pl	pl_PL.UTF-8
 pt_BR	pt_BR.UTF-8
 ru	ru_RU.UTF-8
+sr	sr_RS.UTF-8
 sv	sv_SE.UTF-8
 uk	uk_UA.UTF-8
 vi	vi_VN.UTF-8
diff --git a/po/de.gmo b/po/de.gmo
index 715a802..26d58c0 100644
Binary files a/po/de.gmo and b/po/de.gmo differ
diff --git a/po/de.po b/po/de.po
index 52554b4..b26a2c7 100644
--- a/po/de.po
+++ b/po/de.po
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: help2man 1.39.2\n"
 "Report-Msgid-Bugs-To: Brendan O'Dea <bug-help2man@gnu.org>\n"
-"POT-Creation-Date: 2011-06-20 11:31+1000\n"
+"POT-Creation-Date: 2012-01-02 17:44+1100\n"
 "PO-Revision-Date: 2011-05-01 10:25+1000\n"
 "Last-Translator: Chris Leick <c.leick@vollbio.de>\n"
 "Language-Team: German <debian-l10n-german@lists.debian.org>\n"
@@ -23,7 +23,7 @@ msgid ""
 "\n"
 "Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, "
 "2010,\n"
-"2011 Free Software Foundation, Inc.\n"
+"2011, 2012 Free Software Foundation, Inc.\n"
 "This is free software; see the source for copying conditions.  There is NO\n"
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
 "\n"
@@ -33,7 +33,7 @@ msgstr ""
 "\n"
 "Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, "
 "2010\n"
-"2011 Free Software Foundation, Inc.\n"
+"2011, 2012 Free Software Foundation, Inc.\n"
 "Dies ist freie Software. Lesen Sie die Quelle, um die Kopierbedingungen\n"
 "zu erhalten. Es gibt KEINE Gewährleistung, nicht einmal für\n"
 "MARKTGÄNGIGKEIT oder EIGNUNG FÜR SPEZIELLE ZWECKE.\n"
diff --git a/po/el.gmo b/po/el.gmo
index 607ae97..434e2bf 100644
Binary files a/po/el.gmo and b/po/el.gmo differ
diff --git a/po/el.po b/po/el.po
index c3b3f44..b2d3582 100644
--- a/po/el.po
+++ b/po/el.po
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: help2man 1.38.2 \n"
 "Report-Msgid-Bugs-To: Brendan O'Dea <bug-help2man@gnu.org>\n"
-"POT-Creation-Date: 2011-06-20 11:31+1000\n"
+"POT-Creation-Date: 2012-01-02 17:44+1100\n"
 "PO-Revision-Date: 2010-10-23 00:48+0200\n"
 "Last-Translator: Michael Kotsarinis <mk73628@gmail.com>\n"
 "Language-Team: Greek <team@lists.gnome.gr>\n"
@@ -20,13 +20,13 @@ msgstr ""
 "X-Poedit-Country: GREECE\n"
 
 #: help2man:69
-#, fuzzy, perl-format
+#, perl-format
 msgid ""
 "GNU %s %s\n"
 "\n"
 "Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, "
 "2010,\n"
-"2011 Free Software Foundation, Inc.\n"
+"2011, 2012 Free Software Foundation, Inc.\n"
 "This is free software; see the source for copying conditions.  There is NO\n"
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
 "\n"
@@ -35,8 +35,8 @@ msgstr ""
 "GNU %s %s\n"
 "\n"
 "Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, "
-"2010\n"
-"Free Software Foundation, Inc.\n"
+"2010,\n"
+"2011, 2012 Free Software Foundation, Inc.\n"
 "Αυτό είναι ελεύθερο λογισμικό. Δείτε τον πηγαίο κώδικα για όρους αντιγραφής. "
 "ΔΕΝ δίδεται\n"
 "εγγύηση, ούτε ακόμα ΕΜΠΟΡΕΥΣΙΜΟΤΗΤΑΣ ή ΚΑΤΑΛΛΗΛΟΤΗΤΑΣ ΓΙΑ ΣΥΓΚΕΚΡΙΜΕΝΟ "
diff --git a/po/eo.gmo b/po/eo.gmo
index e72f5db..f4293af 100644
Binary files a/po/eo.gmo and b/po/eo.gmo differ
diff --git a/po/eo.po b/po/eo.po
index 9b2ee68..d4dbcc8 100644
--- a/po/eo.po
+++ b/po/eo.po
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: help2man 1.40.1\n"
 "Report-Msgid-Bugs-To: Brendan O'Dea <bug-help2man@gnu.org>\n"
-"POT-Creation-Date: 2011-06-20 11:31+1000\n"
+"POT-Creation-Date: 2012-01-02 17:44+1100\n"
 "PO-Revision-Date: 2011-06-13 08:30-0300\n"
 "Last-Translator: Felipe Castro <fefcas@gmail.com>\n"
 "Language-Team: Esperanto <translation-team-eo@lists.sourceforge.net>\n"
@@ -23,7 +23,7 @@ msgid ""
 "\n"
 "Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, "
 "2010,\n"
-"2011 Free Software Foundation, Inc.\n"
+"2011, 2012 Free Software Foundation, Inc.\n"
 "This is free software; see the source for copying conditions.  There is NO\n"
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
 "\n"
@@ -33,7 +33,7 @@ msgstr ""
 "\n"
 "Kopirajto (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, "
 "2010,\n"
-"2011 Free Software Foundation, Inc.\n"
+"2011, 2012 Free Software Foundation, Inc.\n"
 "Tio ĉi estas libera programaro; rigardu la fontkodon por kopi-kondiĉoj. "
 "Estas NENIU\n"
 "garantio; eĉ ne por MERKATIGEBLO aŭ TAŬGECO POR SPECIFA CELO.\n"
diff --git a/po/fi.gmo b/po/fi.gmo
index 70aac91..ec81c4f 100644
Binary files a/po/fi.gmo and b/po/fi.gmo differ
diff --git a/po/fi.po b/po/fi.po
index 8571c15..992448a 100644
--- a/po/fi.po
+++ b/po/fi.po
@@ -6,7 +6,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: help2man 1.39.1\n"
 "Report-Msgid-Bugs-To: Brendan O'Dea <bug-help2man@gnu.org>\n"
-"POT-Creation-Date: 2011-06-20 11:31+1000\n"
+"POT-Creation-Date: 2012-01-02 17:44+1100\n"
 "PO-Revision-Date: 2011-03-03 10:08+0200\n"
 "Last-Translator: Tommi Vainikainen <Tommi.Vainikainen@iki.fi>\n"
 "Language-Team: Finnish <translation-team-fi@lists.sourceforge.net>\n"
@@ -23,7 +23,7 @@ msgid ""
 "\n"
 "Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, "
 "2010,\n"
-"2011 Free Software Foundation, Inc.\n"
+"2011, 2012 Free Software Foundation, Inc.\n"
 "This is free software; see the source for copying conditions.  There is NO\n"
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
 "\n"
@@ -33,7 +33,7 @@ msgstr ""
 "\n"
 "Copyright © 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, "
 "2010,\n"
-"2011 Free Software Foundation, Inc.\n"
+"2011, 2012 Free Software Foundation, Inc.\n"
 "Tämä on vapaa ohjelmist; katsokaa kopiointiehdot lähdekoodista. Takuuta EI "
 "OLE;\n"
 "ei edes KAUPALLISESTI HYVÄKSYTTÄVÄSTÄ LAADUSTA tai SOPIVUUDESTA TIETTYYN\n"
diff --git a/po/fr.gmo b/po/fr.gmo
index 8124a65..e91ac63 100644
Binary files a/po/fr.gmo and b/po/fr.gmo differ
diff --git a/po/fr.po b/po/fr.po
index bb15160..5b188fd 100644
--- a/po/fr.po
+++ b/po/fr.po
@@ -8,7 +8,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: help2man 1.40.1\n"
 "Report-Msgid-Bugs-To: Brendan O'Dea <bug-help2man@gnu.org>\n"
-"POT-Creation-Date: 2011-06-20 11:31+1000\n"
+"POT-Creation-Date: 2012-01-02 17:44+1100\n"
 "PO-Revision-Date: 2011-05-31 08:10-0400\n"
 "Last-Translator: David Prévot <david@tilapin.org>\n"
 "Language-Team: French <traduc@traduc.org>\n"
@@ -26,7 +26,7 @@ msgid ""
 "\n"
 "Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, "
 "2010,\n"
-"2011 Free Software Foundation, Inc.\n"
+"2011, 2012 Free Software Foundation, Inc.\n"
 "This is free software; see the source for copying conditions.  There is NO\n"
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
 "\n"
@@ -36,7 +36,7 @@ msgstr ""
 "\n"
 "Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, "
 "2010,\n"
-"2011 Free Software Foundation, Inc.\n"
+"2011, 2012 Free Software Foundation, Inc.\n"
 "Ce logiciel est libre ; voir les sources pour les conditions de\n"
 "reproduction. AUCUNE garantie n'est donnée, pas même la garantie\n"
 "implicite de COMMERCIALISATION ni l'ADAPTATION À UN BESOIN PARTICULIER.\n"
diff --git a/po/help2man.pot b/po/help2man.pot
index 97f549f..c1b5973 100644
--- a/po/help2man.pot
+++ b/po/help2man.pot
@@ -8,7 +8,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: PACKAGE VERSION\n"
 "Report-Msgid-Bugs-To: Brendan O'Dea <bug-help2man@gnu.org>\n"
-"POT-Creation-Date: 2011-06-20 11:31+1000\n"
+"POT-Creation-Date: 2012-01-02 17:44+1100\n"
 "PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
 "Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
 "Language-Team: LANGUAGE <LL@li.org>\n"
@@ -24,7 +24,7 @@ msgid ""
 "\n"
 "Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, "
 "2010,\n"
-"2011 Free Software Foundation, Inc.\n"
+"2011, 2012 Free Software Foundation, Inc.\n"
 "This is free software; see the source for copying conditions.  There is NO\n"
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
 "\n"
diff --git a/po/it.gmo b/po/it.gmo
index 22ca59a..589cee1 100644
Binary files a/po/it.gmo and b/po/it.gmo differ
diff --git a/po/it.po b/po/it.po
index c9406e6..e740d58 100644
--- a/po/it.po
+++ b/po/it.po
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: help2man-1.40.1\n"
 "Report-Msgid-Bugs-To: Brendan O'Dea <bug-help2man@gnu.org>\n"
-"POT-Creation-Date: 2011-06-20 11:31+1000\n"
+"POT-Creation-Date: 2012-01-02 17:44+1100\n"
 "PO-Revision-Date: 2011-05-31 10:01+0200\n"
 "Last-Translator: Sergio Zanchetta <primes2h@ubuntu.com>\n"
 "Language-Team: Italian <tp@lists.linux.it>\n"
@@ -24,7 +24,7 @@ msgid ""
 "\n"
 "Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, "
 "2010,\n"
-"2011 Free Software Foundation, Inc.\n"
+"2011, 2012 Free Software Foundation, Inc.\n"
 "This is free software; see the source for copying conditions.  There is NO\n"
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
 "\n"
@@ -34,7 +34,7 @@ msgstr ""
 "\n"
 "Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, "
 "2010,\n"
-"2011 Free Software Foundation, Inc.\n"
+"2011, 2012 Free Software Foundation, Inc.\n"
 "Questo è software libero; si vedano i sorgenti per le condizioni di copia.\n"
 "NON c'è alcuna garanzia; neppure di COMMERCIABILITÀ o di IDONEITÀ A UNO\n"
 "SCOPO PARTICOLARE.\n"
@@ -319,8 +319,8 @@ msgstr ""
 "opzioni\n"
 ".B \\-\\-include\n"
 "e\n"
-".B \\-\\-opt\\-include\n"
-".  Il formato è semplice:\n"
+".BR \\-\\-opt\\-include .\n"
+"Il formato è semplice:\n"
 "\n"
 "    [sezione]\n"
 "    testo\n"
diff --git a/po/ja.gmo b/po/ja.gmo
index a7d96f9..a91baa4 100644
Binary files a/po/ja.gmo and b/po/ja.gmo differ
diff --git a/po/ja.po b/po/ja.po
index ce3f848..0beb629 100644
--- a/po/ja.po
+++ b/po/ja.po
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: help2man 1.40.1\n"
 "Report-Msgid-Bugs-To: Brendan O'Dea <bug-help2man@gnu.org>\n"
-"POT-Creation-Date: 2011-06-20 11:31+1000\n"
+"POT-Creation-Date: 2012-01-02 17:44+1100\n"
 "PO-Revision-Date: 2011-05-31 21:32+0900\n"
 "Last-Translator: Yasumichi Akahoshi <yasumichi@vinelinux.org>\n"
 "Language-Team: Japanese <translation-team-ja@lists.sourceforge.net>\n"
@@ -24,7 +24,7 @@ msgid ""
 "\n"
 "Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, "
 "2010,\n"
-"2011 Free Software Foundation, Inc.\n"
+"2011, 2012 Free Software Foundation, Inc.\n"
 "This is free software; see the source for copying conditions.  There is NO\n"
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
 "\n"
@@ -34,7 +34,7 @@ msgstr ""
 "\n"
 "Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, "
 "2010,\n"
-"2011 Free Software Foundation, Inc.\n"
+"2011, 2012 Free Software Foundation, Inc.\n"
 "This is free software; see the source for copying conditions.  There is NO\n"
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
 "\n"
diff --git a/po/pl.gmo b/po/pl.gmo
index b64e9e5..98c57e8 100644
Binary files a/po/pl.gmo and b/po/pl.gmo differ
diff --git a/po/pl.po b/po/pl.po
index 2f5bb74..7dd7003 100644
--- a/po/pl.po
+++ b/po/pl.po
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: help2man 1.40.1\n"
 "Report-Msgid-Bugs-To: Brendan O'Dea <bug-help2man@gnu.org>\n"
-"POT-Creation-Date: 2011-06-20 11:31+1000\n"
+"POT-Creation-Date: 2012-01-02 17:44+1100\n"
 "PO-Revision-Date: 2011-05-31 19:25+0200\n"
 "Last-Translator: Jakub Bogusz <qboosh@pld-linux.org>\n"
 "Language-Team: Polish <translation-team-pl@lists.sourceforge.net>\n"
@@ -23,7 +23,7 @@ msgid ""
 "\n"
 "Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, "
 "2010,\n"
-"2011 Free Software Foundation, Inc.\n"
+"2011, 2012 Free Software Foundation, Inc.\n"
 "This is free software; see the source for copying conditions.  There is NO\n"
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
 "\n"
@@ -33,7 +33,7 @@ msgstr ""
 "\n"
 "Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, "
 "2010,\n"
-"2011 Free Software Foundation, Inc.\n"
+"2011, 2012 Free Software Foundation, Inc.\n"
 "Ten program jest darmowy; warunki kopiowania s opisane w rdach.\n"
 "Autorzy nie daj ADNYCH gwarancji, w tym rwnie gwarancji PRZYDATNOCI\n"
 "DO SPRZEDAY LUB DO KONKRETNYCH CELW.\n"
diff --git a/po/pt_BR.gmo b/po/pt_BR.gmo
index 0d94d9f..c7ef140 100644
Binary files a/po/pt_BR.gmo and b/po/pt_BR.gmo differ
diff --git a/po/pt_BR.po b/po/pt_BR.po
index e22bd89..a898f87 100644
--- a/po/pt_BR.po
+++ b/po/pt_BR.po
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: help2man 1.40.1\n"
 "Report-Msgid-Bugs-To: Brendan O'Dea <bug-help2man@gnu.org>\n"
-"POT-Creation-Date: 2011-06-20 11:31+1000\n"
+"POT-Creation-Date: 2012-01-02 17:44+1100\n"
 "PO-Revision-Date: 2011-06-20 12:33+1000\n"
 "Last-Translator: Rodolfo Ribeiro Gomes <rodolforg@gmail.com>\n"
 "Language-Team: Brazilian Portuguese <ldp-br@bazar.conectiva.com.br>\n"
@@ -24,7 +24,7 @@ msgid ""
 "\n"
 "Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, "
 "2010,\n"
-"2011 Free Software Foundation, Inc.\n"
+"2011, 2012 Free Software Foundation, Inc.\n"
 "This is free software; see the source for copying conditions.  There is NO\n"
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
 "\n"
@@ -34,7 +34,7 @@ msgstr ""
 "\n"
 "Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, "
 "2010,\n"
-"2011 Free Software Foundation, Inc.\n"
+"2011, 2012 Free Software Foundation, Inc.\n"
 "Este é um software livre; veja o código-fonte para as condições de cópia.\n"
 "NÃO HÁ GARANTIAS; nem mesmo para COMERCIALIZAÇÃO ou ADAPTAÇÃO PARA UM\n"
 "FIM ESPECÍFICO.\n"
diff --git a/po/ru.gmo b/po/ru.gmo
index 6a0af62..2126251 100644
Binary files a/po/ru.gmo and b/po/ru.gmo differ
diff --git a/po/ru.po b/po/ru.po
index 4f1965e..b443677 100644
--- a/po/ru.po
+++ b/po/ru.po
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: help2man 1.40.1\n"
 "Report-Msgid-Bugs-To: Brendan O'Dea <bug-help2man@gnu.org>\n"
-"POT-Creation-Date: 2011-06-20 11:31+1000\n"
+"POT-Creation-Date: 2012-01-02 17:44+1100\n"
 "PO-Revision-Date: 2011-05-31 20:24+0400\n"
 "Last-Translator: Yuri Kozlov <yuray@komyakino.ru>\n"
 "Language-Team: Russian <gnu@mx.ru>\n"
@@ -26,7 +26,7 @@ msgid ""
 "\n"
 "Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, "
 "2010,\n"
-"2011 Free Software Foundation, Inc.\n"
+"2011, 2012 Free Software Foundation, Inc.\n"
 "This is free software; see the source for copying conditions.  There is NO\n"
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
 "\n"
@@ -36,7 +36,7 @@ msgstr ""
 "\n"
 "Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, "
 "2010,\n"
-"2011 Free Software Foundation, Inc.\n"
+"2011, 2012 Free Software Foundation, Inc.\n"
 "Это свободное ПО; условия копирования см. в исходном коде.\n"
 "Нет НИКАКИХ ГАРАНТИЙ; даже подразумеваемыми гарантиями\n"
 "КОММЕРЧЕСКОЙ ЦЕННОСТИ и ПРИГОДНОСТИ ДЛЯ КОНКРЕТНОЙ ЦЕЛИ.\n"
diff --git a/po/sr.gmo b/po/sr.gmo
new file mode 100644
index 0000000..a1ab487
Binary files /dev/null and b/po/sr.gmo differ
diff --git a/po/sr.po b/po/sr.po
new file mode 100644
index 0000000..3e2d29e
--- /dev/null
+++ b/po/sr.po
@@ -0,0 +1,412 @@
+# Serbian translation of help2man.
+# Copyright (C) 2011 Free Software Foundation, Inc.
+# This file is distributed under the same license as the help2man package.
+# Мирослав Николић <miroslavnikolic@rocketmail.com>, 2011.
+msgid ""
+msgstr ""
+"Project-Id-Version: help2man-1.40.4\n"
+"Report-Msgid-Bugs-To: Brendan O'Dea <bug-help2man@gnu.org>\n"
+"POT-Creation-Date: 2012-01-02 17:44+1100\n"
+"PO-Revision-Date: 2011-12-29 10:56+0200\n"
+"Last-Translator: Мирослав Николић <miroslavnikolic@rocketmail.com>\n"
+"Language-Team: Serbian <gnu@prevod.org>\n"
+"Language: sr\n"
+"MIME-Version: 1.0\n"
+"Content-Type: text/plain; charset=UTF-8\n"
+"Content-Transfer-Encoding: 8bit\n"
+"Plural-Forms: nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);\n"
+
+#: help2man:69
+#, perl-format
+msgid ""
+"GNU %s %s\n"
+"\n"
+"Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, 2010,\n"
+"2011, 2012 Free Software Foundation, Inc.\n"
+"This is free software; see the source for copying conditions.  There is NO\n"
+"warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
+"\n"
+"Written by Brendan O'Dea <bod@debian.org>\n"
+msgstr ""
+"ГНУ %s %s\n"
+"\n"
+"Ауторска права (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, 2010,\n"
+"2011, 2012 Задужбина слободног софтвера, Инц.\n"
+"Ово је слободан софтвер; погледајте извор за услове умножавања.  Нема НИКАКВЕ\n"
+"гаранције; чак ни за ТРЖИШНУ ВРЕДНОСТ или ПРИЛАГОЂЕНОСТИ ПОСЕБНОЈ НАМЕНИ.\n"
+"\n"
+"Написао је Брендан О'Деа <bod@debian.org>\n"
+
+#: help2man:80
+#, perl-format
+msgid ""
+"`%s' generates a man page out of `--help' and `--version' output.\n"
+"\n"
+"Usage: %s [OPTION]... EXECUTABLE\n"
+"\n"
+" -n, --name=STRING       description for the NAME paragraph\n"
+" -s, --section=SECTION   section number for manual page (1, 6, 8)\n"
+" -m, --manual=TEXT       name of manual (User Commands, ...)\n"
+" -S, --source=TEXT       source of program (FSF, Debian, ...)\n"
+" -L, --locale=STRING     select locale (default \"C\")\n"
+" -i, --include=FILE      include material from `FILE'\n"
+" -I, --opt-include=FILE  include material from `FILE' if it exists\n"
+" -o, --output=FILE       send output to `FILE'\n"
+" -p, --info-page=TEXT    name of Texinfo manual\n"
+" -N, --no-info           suppress pointer to Texinfo manual\n"
+" -l, --libtool           exclude the `lt-' from the program name\n"
+"     --help              print this help, then exit\n"
+"     --version           print version number, then exit\n"
+"\n"
+"EXECUTABLE should accept `--help' and `--version' options and produce output on\n"
+"stdout although alternatives may be specified using:\n"
+"\n"
+" -h, --help-option=STRING     help option string\n"
+" -v, --version-option=STRING  version option string\n"
+" --version-string=STRING      version string\n"
+" --no-discard-stderr          include stderr when parsing option output\n"
+"\n"
+"Report bugs to <bug-help2man@gnu.org>.\n"
+msgstr ""
+"„%s“ ствара странице упутства из „--help“ и „--version“ излаза.\n"
+"\n"
+"Употреба: %s [ОПЦИЈА]... ИЗВРШНИ\n"
+"\n"
+" -n, --name=НИСКА            опис пасуса НАЗИВ\n"
+" -s, --section=ОДЕЉАК        број одељка за страницу упутства (1, 6, 8)\n"
+" -m, --manual=ТЕКСТ          назив упутства (Корисничке наредбе, ...)\n"
+" -S, --source=ТЕКСТ          извор програма (3ЦЦ, Дебијан, ...)\n"
+" -L, --locale=НИСКА          бира локалитет (основно је \"C\")\n"
+" -i, --include=ДАТОТЕКА      укључује материјал из „ДАТОТЕКЕ“\n"
+" -I, --opt-include=ДАТОТЕКА  укључује материјал из ДАТОТЕКЕ ако постоји\n"
+" -o, --output=ДАТОТЕКА       шаље излаз у ДАТОТЕКУ\n"
+" -p, --info-page=ТЕКСТ       назив Тексинфо упутства\n"
+" -N, --no-info               потискује указивач на Тексинфо упутства\n"
+" -l, --libtool               искључује „lt-“ из назива програма\n"
+"     --help                  исписује ову помоћ, затим излази\n"
+"     --version               исписује број издања, затим излази\n"
+"\n"
+"ИЗВРШНИ треба да прихвати „--help“ и „--version“ опције и да произведе излаз\n"
+"на стандардном излазу иако алтернативе могу бити наведене користећи:\n"
+"\n"
+" -h, --help-option=НИСКА     ниска опције помоћи\n"
+" -v, --version-option=НИСКА  ниска опције издања\n"
+" --version-string=НИСКА      ниска издања\n"
+" --no-discard-stderr         укључује стандардну грешку при обради излаза опције\n"
+"\n"
+"Грешке пријавите на <bug-help2man@gnu.org>.\n"
+
+#: help2man:164
+#, perl-format
+msgid "%s: can't open `%s' (%s)"
+msgstr "%s: не могу да отворим „%s“ (%s)"
+
+#: help2man:225
+#, perl-format
+msgid "%s: no valid information found in `%s'"
+msgstr "%s: нисам пронашао исправне информације у „%s“"
+
+#. Translators: the following message is a strftime(3) format string, which in
+#. the English version expands to the month as a word and the full year.  It
+#. is used on the footer of the generated manual pages.  If in doubt, you may
+#. just use %x as the value (which should be the full locale-specific date).
+#: help2man:245
+msgid "%B %Y"
+msgstr "%B %Y."
+
+#: help2man:252
+#, perl-format
+msgid "%s: can't unlink %s (%s)"
+msgstr "%s: не могу да поништим везу „%s“ (%s)"
+
+#: help2man:256
+#, perl-format
+msgid "%s: can't create %s (%s)"
+msgstr "%s: не могу да направим „%s“ (%s)"
+
+#. Translators: "NAME", "SYNOPSIS" and other one or two word strings in all
+#. upper case are manual page section headings.  The man(1) manual page in your
+#. language, if available should provide the conventional translations.
+#: help2man:298 help2man:620 help2man.h2m.PL:79 help2man.h2m.PL:129
+msgid "NAME"
+msgstr "НАЗИВ"
+
+#: help2man:310
+#, perl-format
+msgid "%s \\- manual page for %s %s"
+msgstr "%s \\— страница упутства за %s %s"
+
+#: help2man:324
+msgid "System Administration Utilities"
+msgstr "Помагала за администрацију система"
+
+#: help2man:325
+msgid "Games"
+msgstr "Игре"
+
+#: help2man:326
+msgid "User Commands"
+msgstr "Корисничке наредбе"
+
+#. Translators: "Usage" and "or" here are patterns (regular expressions) which
+#. are used to match the usage synopsis in program output.  An example from cp
+#. (GNU coreutils) which contains both strings:
+#. Usage: cp [OPTION]... [-T] SOURCE DEST
+#. or:  cp [OPTION]... SOURCE... DIRECTORY
+#. or:  cp [OPTION]... -t DIRECTORY SOURCE...
+#: help2man:337
+msgid "Usage"
+msgstr "Употреба"
+
+#: help2man:338
+msgid "or"
+msgstr "или"
+
+#: help2man:370 help2man:620 help2man.h2m.PL:130
+msgid "SYNOPSIS"
+msgstr "УВОД"
+
+#: help2man:374 help2man:620 help2man.h2m.PL:131
+msgid "DESCRIPTION"
+msgstr "ОПИС"
+
+#. Translators: patterns are used to match common program output. In the source
+#. these strings are all of the form of "my $PAT_something = _('...');" and are
+#. regular expressions.  If there is more than one commonly used string, you
+#. may separate alternatives with "|".  Spaces in these expressions are written
+#. as " +" to indicate that more than one space may be matched.  The string
+#. "(?:[\\w-]+ +)?" in the bug reporting pattern is used to indicate an
+#. optional word, so that either "Report bugs" or "Report _program_ bugs" will
+#. be matched.
+#: help2man:399
+msgid "Report +(?:[\\w-]+ +)?bugs|Email +bug +reports +to"
+msgstr "Пријавите +(?:[\\w-]+ +)?грешке|Пошаљите +извештаје +о +грешкама +на"
+
+#: help2man:400
+msgid "Written +by"
+msgstr "Написали +су"
+
+#: help2man:401
+msgid "Options"
+msgstr "Опције"
+
+#: help2man:402
+msgid "Environment"
+msgstr "Окружење"
+
+#: help2man:403
+msgid "Files"
+msgstr "Датотеке"
+
+#: help2man:404
+msgid "Examples"
+msgstr "Примери"
+
+#: help2man:405
+msgid "This +is +free +software"
+msgstr "Ово +је +слободан +софтвер"
+
+#: help2man:421 help2man:620 help2man.h2m.PL:132
+msgid "OPTIONS"
+msgstr "ОПЦИЈЕ"
+
+#: help2man:426 help2man:621 help2man.h2m.PL:133
+msgid "ENVIRONMENT"
+msgstr "ОКРУЖЕЊЕ"
+
+#: help2man:431 help2man:621 help2man.h2m.PL:134
+msgid "FILES"
+msgstr "ДАТОТЕКЕ"
+
+#: help2man:436 help2man:621 help2man.h2m.PL:135
+msgid "EXAMPLES"
+msgstr "ПРИМЕРИ"
+
+#: help2man:443 help2man:623 help2man.h2m.PL:139
+msgid "COPYRIGHT"
+msgstr "АУТОРСКА ПРАВА"
+
+#: help2man:449 help2man:623 help2man.h2m.PL:138
+msgid "REPORTING BUGS"
+msgstr "ПРИЈАВЉИВАЊЕ ГРЕШАКА"
+
+#: help2man:455 help2man:623 help2man.h2m.PL:137
+msgid "AUTHOR"
+msgstr "АУТОР"
+
+#: help2man:595 help2man:623 help2man.h2m.PL:140
+msgid "SEE ALSO"
+msgstr "ПОГЛЕДАЈТЕ ТАКОЂЕ"
+
+#: help2man:599
+#, perl-format
+msgid ""
+"The full documentation for\n"
+".B %s\n"
+"is maintained as a Texinfo manual.  If the\n"
+".B info\n"
+"and\n"
+".B %s\n"
+"programs are properly installed at your site, the command\n"
+".IP\n"
+".B info %s\n"
+".PP\n"
+"should give you access to the complete manual.\n"
+msgstr ""
+"Потпуна документација за\n"
+".B %s\n"
+"је одржавана као Тексинфо упутство.  Ако су\n"
+".B инфо\n"
+"и\n"
+".B %s\n"
+"исправно инсталирани на вашем сајту, наредба\n"
+".IP\n"
+".B инфо %s\n"
+".PP\n"
+"треба да вам да приступ потпуном упутству.\n"
+
+#: help2man:651
+#, perl-format
+msgid "%s: error writing to %s (%s)"
+msgstr "%s: грешка приликом писања у %s (%s)"
+
+#: help2man:668
+#, perl-format
+msgid "%s: can't get `%s' info from %s%s"
+msgstr "%s: не могу да добавим „%s“ инфо са %s%s"
+
+#: help2man:670
+msgid "Try `--no-discard-stderr' if option outputs to stderr"
+msgstr "Покушајте „--no-discard-stderr“ ако опција шаље резултат у стандардну грешку"
+
+#: help2man.h2m.PL:74
+msgid "Include file for help2man man page"
+msgstr "Укључи датотеку за страницу упутства хелп2мана"
+
+#: help2man.h2m.PL:80
+msgid "help2man \\- generate a simple manual page"
+msgstr "help2man \\— ствара страницу упутства"
+
+#: help2man.h2m.PL:83
+msgid "INCLUDE FILES"
+msgstr "УКЉУЧИ ДАТОТЕКЕ"
+
+#: help2man.h2m.PL:85
+msgid ""
+"Additional material may be included in the generated output with the\n"
+".B \\-\\-include\n"
+"and\n"
+".B \\-\\-opt\\-include\n"
+"options.  The format is simple:\n"
+"\n"
+"    [section]\n"
+"    text\n"
+"\n"
+"    /pattern/\n"
+"    text\n"
+msgstr ""
+"Додатни материјал може бити укључен у створени резултат употребом\n"
+".B \\-\\-include\n"
+"и\n"
+".B \\-\\-opt\\-include\n"
+"опцијом.  Облик је једноставан:\n"
+"\n"
+"    [одељак]\n"
+"    текст\n"
+"\n"
+"    /шаблон/\n"
+"    текст\n"
+
+#: help2man.h2m.PL:100
+msgid ""
+"Blocks of verbatim *roff text are inserted into the output either at\n"
+"the start of the given\n"
+".BI [ section ]\n"
+"(case insensitive), or after a paragraph matching\n"
+".BI / pattern /\\fR.\n"
+msgstr ""
+"Блокови дословног *рофф текста су уметнути у резултату било на\n"
+"почетку датог\n"
+".BI [ одељка ]\n"
+"(неосетљив на величину слова), или након поклапања пасуса са\n"
+".BI / шаблоном /\\fR.\n"
+
+#: help2man.h2m.PL:109
+msgid ""
+"Patterns use the Perl regular expression syntax and may be followed by\n"
+"the\n"
+".IR i ,\n"
+".I s\n"
+"or\n"
+".I m\n"
+"modifiers (see\n"
+".BR perlre (1)).\n"
+msgstr ""
+"Шаблони користе синтаксу регуларног израза Перла и за њима могу да\n"
+"стоје\n"
+".IR i ,\n"
+".I s\n"
+"или\n"
+".I m\n"
+"измењивачи (погледајте\n"
+".BR perlre (1)).\n"
+
+#: help2man.h2m.PL:121
+msgid ""
+"Lines before the first section or pattern which begin with `\\-' are\n"
+"processed as options.  Anything else is silently ignored and may be\n"
+"used for comments, RCS keywords and the like.\n"
+msgstr ""
+"Редови пре првог одељка или шаблона који почињу са „\\-“ се\n"
+"обрађују као опције.  Све остало се немо занемарује и може бити\n"
+"коришћено за напомене, РЦС кључне речи и слично.\n"
+
+#: help2man.h2m.PL:127
+msgid "The section output order (for those included) is:"
+msgstr "Поредак резултата одељка (за оне укључене) је:"
+
+#: help2man.h2m.PL:136
+msgid "other"
+msgstr "остало"
+
+#: help2man.h2m.PL:144
+msgid ""
+"Any\n"
+".B [NAME]\n"
+"or\n"
+".B [SYNOPSIS]\n"
+"sections appearing in the include file will replace what would have\n"
+"automatically been produced (although you can still override the\n"
+"former with\n"
+".B --name\n"
+"if required).\n"
+msgstr ""
+"Сваки\n"
+".B [НАЗИВ]\n"
+"или\n"
+".B [УВОД]\n"
+"одељак који се појави у датотеци укључивања ће заменити оно што је\n"
+"самостално произведено (ипак можете још увек да прескочите\n"
+"модел са\n"
+".B --name\n"
+"ако је затражено).\n"
+
+#: help2man.h2m.PL:157
+msgid ""
+"Other sections are prepended to the automatically produced output for\n"
+"the standard sections given above, or included at\n"
+".I other\n"
+"(above) in the order they were encountered in the include file.\n"
+msgstr ""
+"Остали одељци су прикачени самостално произведеном резултату за\n"
+"стандардне одељке дате изнад, или укључени у\n"
+".I осталим\n"
+"(изнад) по редоследу како су проналажени у датотеци укључивања.\n"
+
+#: help2man.h2m.PL:164
+msgid "AVAILABILITY"
+msgstr "ДОСТУПНОСТ"
+
+#: help2man.h2m.PL:165
+msgid "The latest version of this distribution is available on-line from:"
+msgstr "Најновије издање ове расподеле је доступно на мрежи са:"
diff --git a/po/sv.gmo b/po/sv.gmo
index a6ac867..23017ba 100644
Binary files a/po/sv.gmo and b/po/sv.gmo differ
diff --git a/po/sv.po b/po/sv.po
index f04eaa9..eae4029 100644
--- a/po/sv.po
+++ b/po/sv.po
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: help2man 1.36.3\n"
 "Report-Msgid-Bugs-To: Brendan O'Dea <bug-help2man@gnu.org>\n"
-"POT-Creation-Date: 2011-06-20 11:31+1000\n"
+"POT-Creation-Date: 2012-01-02 17:44+1100\n"
 "PO-Revision-Date: 2006-01-23 20:33+0100\n"
 "Last-Translator: Daniel Nylander <po@danielnylander.se>\n"
 "Language-Team: Swedish <tp-sv@listor.tp-sv.se>\n"
@@ -17,13 +17,13 @@ msgstr ""
 "Content-Transfer-Encoding: 8bit\n"
 
 #: help2man:69
-#, fuzzy, perl-format
+#, perl-format
 msgid ""
 "GNU %s %s\n"
 "\n"
 "Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, "
 "2010,\n"
-"2011 Free Software Foundation, Inc.\n"
+"2011, 2012 Free Software Foundation, Inc.\n"
 "This is free software; see the source for copying conditions.  There is NO\n"
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
 "\n"
@@ -32,8 +32,8 @@ msgstr ""
 "GNU %s %s\n"
 "\n"
 "Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, "
-"2010\n"
-"Free Software Foundation, Inc.\n"
+"2010,\n"
+"2011, 2012 Free Software Foundation, Inc.\n"
 "Det här är fri programvara; se källkoden för kopieringsvillkor.  Det finns "
 "INGEN\n"
 "garanti; inte ens för SÄLJBARHET eller LÄMPLIGHET FÖR SPECIELLT ÄNDAMÅL.\n"
diff --git a/po/uk.gmo b/po/uk.gmo
index 792c31a..e1c34e1 100644
Binary files a/po/uk.gmo and b/po/uk.gmo differ
diff --git a/po/uk.po b/po/uk.po
index 1f4e6dd..b4d2948 100644
--- a/po/uk.po
+++ b/po/uk.po
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: help2man 1.40.1\n"
 "Report-Msgid-Bugs-To: Brendan O'Dea <bug-help2man@gnu.org>\n"
-"POT-Creation-Date: 2011-06-20 11:31+1000\n"
+"POT-Creation-Date: 2012-01-02 17:44+1100\n"
 "PO-Revision-Date: 2011-05-31 11:30+0200\n"
 "Last-Translator: Yuri Chornoivan <yurchor@ukr.net>\n"
 "Language-Team: Ukrainian <translation-team-uk@lists.sourceforge.net>\n"
@@ -25,7 +25,7 @@ msgid ""
 "\n"
 "Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, "
 "2010,\n"
-"2011 Free Software Foundation, Inc.\n"
+"2011, 2012 Free Software Foundation, Inc.\n"
 "This is free software; see the source for copying conditions.  There is NO\n"
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
 "\n"
@@ -34,7 +34,7 @@ msgstr ""
 "GNU %s %s\n"
 "\n"
 "© Free Software Foundation, Inc., 1997, 1998, 1999, 2000, 2001, 2002, 2003, "
-"2004, 2005, 2009, 2010, 2011\n"
+"2004, 2005, 2009, 2010, 2011, 2012\n"
 "Це програмне забезпечення є вільним, умови копіювання викладено у його "
 "початкових кодах. Умовами ліцензування програми НЕ передбачено жодних "
 "гарантій, зокрема гарантій працездатності або придатності для певної мети.\n"
diff --git a/po/vi.gmo b/po/vi.gmo
index 30ce2bb..3560f6f 100644
Binary files a/po/vi.gmo and b/po/vi.gmo differ
diff --git a/po/vi.po b/po/vi.po
index 433c6e0..cd9aa0e 100644
--- a/po/vi.po
+++ b/po/vi.po
@@ -7,7 +7,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: help2man 1.38.1-pre1\n"
 "Report-Msgid-Bugs-To: Brendan O'Dea <bug-help2man@gnu.org>\n"
-"POT-Creation-Date: 2011-06-20 11:31+1000\n"
+"POT-Creation-Date: 2012-01-02 17:44+1100\n"
 "PO-Revision-Date: 2010-04-13 20:28+0930\n"
 "Last-Translator: Clytie Siddall <clytie@riverland.net.au>\n"
 "Language-Team: Vietnamese <vi-VN@googlegroups.com>\n"
@@ -25,7 +25,7 @@ msgid ""
 "\n"
 "Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, "
 "2010,\n"
-"2011 Free Software Foundation, Inc.\n"
+"2011, 2012 Free Software Foundation, Inc.\n"
 "This is free software; see the source for copying conditions.  There is NO\n"
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
 "\n"
diff --git a/help2man.PL b/help2man.PL
index 2646374..af908cb 100755
--- a/help2man.PL
+++ b/help2man.PL
@@ -16,7 +16,7 @@ use 5.008;
 use Config;
 use Getopt::Long;
 
-my ($program, $version) = ('help2man', '1.40.4');
+my ($program, $version) = ('help2man', '1.40.5');
 
 my %opts;
 die "Usage: $0 [--quiet] [--stdout] [--with-gettext] [--name] [--version]\n"
@@ -59,8 +59,8 @@ eval 'exec $Config{perlpath} -wS \$0 \${1+"\$@"}'
 print OUT <<'!NO!SUBS!';
 
 # Generate a short man page from --help and --version output.
 # Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, 2010,
 # 2011 Free Software Foundation, Inc.
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -156,7 +156,7 @@ my $version_info = enc_user sprintf _(<<'EOT'), $this_program, $this_version;
 GNU %s %s
 
 Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, 2010,
-2011 Free Software Foundation, Inc.
+2011, 2012 Free Software Foundation, Inc.
 This is free software; see the source for copying conditions.  There is NO
 warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 
@@ -59,8 +59,8 @@ eval 'exec $Config{perlpath} -wS \$0 \${1+"\$@"}'
 
 # Generate a short man page from --help and --version output.
-# Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009, 2010,
-# 2011 Free Software Foundation, Inc.
+# Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2009,
+# 2010, 2011, 2012 Free Software Foundation, Inc.
 
 # This program is free software; you can redistribute it and/or modify